==> alfresco-repository-23.7.0.3-sources.jar: org/alfresco/repo/action/executer/LoggingAwareExecuter.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.action.executer;

import org.apache.commons.logging.Log;

public interface LoggingAwareExecuter
{
    /**
     * Optional logging of errors callback for the action executer
     * for the cases when the error might be ignored 
     * or shown in a different manner for the action
     * @param logger the logger
     * @param t the exception thrown
     * @param message the proposed message that will be logged
     * @return true if it was handled, false for default handling
     */
    boolean onLogException(Log logger, Throwable t, String message);
}

==> alfresco-repository-25.3.0.69-sources.jar: org/alfresco/repo/action/executer/LoggingAwareExecuter.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.action.executer;

import org.apache.commons.logging.Log;

public interface LoggingAwareExecuter
{
    /**
     * Optional logging of errors callback for the action executer for the cases when the error might be ignored or shown in a different manner for the action
     * 
     * @param logger
     *            the logger
     * @param t
     *            the exception thrown
     * @param message
     *            the proposed message that will be logged
     * @return true if it was handled, false for default handling
     */
    boolean onLogException(Log logger, Throwable t, String message);
}
